#
# spec file for package gnome-sound-recorder
#
# Copyright (c) 2022 SUSE LLC
# Copyright (c) 2013 Dominique Leuenberger, Amsterdam, The Netherlands.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gnome-sound-recorder
Version:        43.beta
Release:        1.3
Summary:        Sound Recorder
License:        BSD-3-Clause AND LGPL-2.0-or-later
Group:          Productivity/Multimedia/Sound/Utilities
URL:            https://wiki.gnome.org/Design/Apps/SoundRecorder
Source0:        https://download.gnome.org/sources/gnome-sound-recorder/43/%{name}-%{version}.tar.xz

BuildRequires:  appstream-glib
BuildRequires:  desktop-file-utils
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gio-2.0) >= 2.43.4
BuildRequires:  pkgconfig(gjs-1.0) >= 1.54.0
BuildRequires:  pkgconfig(glib-2.0) >= 2.39.3
BuildRequires:  pkgconfig(gobject-introspection-1.0) >= 1.31.6
BuildRequires:  pkgconfig(gstreamer-1.0)
BuildRequires:  pkgconfig(gstreamer-pbutils-1.0)
BuildRequires:  pkgconfig(gstreamer-player-1.0) >= 1.12
BuildRequires:  pkgconfig(gtk4)
BuildRequires:  pkgconfig(libadwaita-1)
Requires:       gjs
Requires:       gstreamer-plugins-base
Requires:       gstreamer-plugins-good
BuildArch:      noarch

%description
A simple, modern sound recorder.

%lang_package

%prep
%autosetup -p1

%build
%meson \
	--libdir=/usr/unused-in-noarch
	%{nil}
%meson_build

%install
%meson_install
%find_lang org.gnome.SoundRecorder

%check
%meson_test

%files
%license COPYING
%doc README.md NEWS AUTHORS
%{_bindir}/%{name}
%dir %{_datadir}/org.gnome.SoundRecorder
%{_datadir}/org.gnome.SoundRecorder/org.gnome.SoundRecorder
%{_datadir}/org.gnome.SoundRecorder/org.gnome.SoundRecorder.data.gresource
%{_datadir}/org.gnome.SoundRecorder/org.gnome.SoundRecorder.src.gresource
%{_datadir}/applications/org.gnome.SoundRecorder.desktop
%{_datadir}/glib-2.0/schemas/org.gnome.SoundRecorder.gschema.xml
%{_datadir}/icons/hicolor/*/apps/org.gnome.SoundRecorder*
%{_datadir}/metainfo/org.gnome.SoundRecorder.metainfo.xml

%files lang -f org.gnome.SoundRecorder.lang

%changelog
* Sun Aug  7 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.beta:
  + Port to AdwAboutWindow.
  + Updated translations.
* Sun Mar 20 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.0:
  + Updated translations.
* Mon Feb 14 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.beta:
  + Port to GTK4 / libadwaita
  + Proper dark theme support
  + Fix build with meson 0.60 and newer.
  + Updated translations.
- Replace pkgconfig(gtk+-3.0) and pkgconfig(libhandy-1) with
  pkgconfig(gtk4) and pkgconfig(libadwaita-1) BuildRequires
  following upstreams port.
- Add explicit pkgconfig(gstreamer-1.0) and
  pkgconfig(gstreamer-pbutils-1.0): meson checks for them.
- Drop gstreamer-plugins-bad Requires: No longer needed, all the
  needed codecs are now in base or good.
- Drop 1335b1b1aff61167f8648f7cb3c569764031960d.patch: Fixed
  upstream.
* Wed Feb  2 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Add 1335b1b1aff61167f8648f7cb3c569764031960d.patch: Fix build
  with meson 0.60 and newer.
- Drop gnome-sound-recorder-rpmlintrc, no longer needed.
- Drop update-desktop-files BuildRequires and macro, no longer
  needed.
- Add desktop-file-utils, and add a check section and run
  meson_test macro, validate desktop file and metadata during build
  via upstream provided tests.
* Wed Mar 24 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 40.0:
  + Updated translations.
* Tue Feb 16 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 40.beta:
  + Updated translations.
* Sun Jan 31 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.38.1:
  + Fix export dialog for recordings disappears shortly after
    opening.
  + Fix not able to use space bar in recording name input.
  + Fix recording is lost when using space bar in name input.
  + Fix ui becomes unusable and recording is lost after stopping a
    record.
  + Remove m4a option since using it results in unusable
    recordings.
  + Updated translations.
* Mon Oct  5 2020 dimstar@opensuse.org
- Update to version 3.38.0:
  + An overall update of Sound Recorder's design:
  - The possibility to seek backward/forward while playing a
    recording.
  - Recordings now always display the associated wave.
  - The possiblity to export a recording.
  - Code cleanup and translations updates.
- Add pkgconfig(gstreamer-player-1.0) and pkgconfig(libhandy-1)
  BuildRequires: new dependencies.
* Thu Aug 13 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Require gjs: /usr/bin/gnome-sound-recorder is a script using
  /usr/bin/gjs-console as interpreter (boo#1169340).
* Sat Jan 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Wed Nov  6 2019 Michael Gorse <mgorse@suse.com>
- Don't use arch-specific libdir (boo#1109687).
* Wed Sep 18 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.0:
  + Add dual installation support.
  + Updated translations.
* Wed Jun  5 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.1:
  + Keep the same app ID as in 3.30 in the appdata file.
  + Add release and OARS tags to appdata file.
  + Updated translations.
* Tue Mar 12 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.0:
  + Updated translations.
* Tue Mar  5 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.31.92:
  + Updated translations.
* Sun Feb 17 2019 bjorn.lie@gmail.com
- Update to version 3.31.90:
  + Drop application menu.
  + Port to meson.
  + Various translation fixes.
  + Drop git.mk - it's an autotools leftover.
  + Set a minimium width and height size.
  + Make record button a "suggested action".
  + Require gtk +> 3.13.2.
  + Remove old RTL hacks.
  + Fix crashes when selecting a recording.
  + Fix gjs "Too many arguments" warnings.
  + Set a default window title for zero sounds recorded.
  + Validate appdata and desktop files.
  + Use same application id everywhere in the app.
  + Use latest GJS standards for variable and class declarations.
  + Port to ES6 classes.
  + New icon.
  + Updated translations.
- Switch to meson build system, add meson BuildRequires and macros.
- Drop obsolete intltool, pkgconfig(gobject-2.0),
  pkgconfig(gdk-3.0) and  pkgconfig(gdk-pixbuf-2.0) BuildRequires,
  no longer needed.
- Replace gjs with pkgconfig(gjs-1.0) BuildRequires.
- Add appstream-glib BuildRequires.
- Drop pkgconfig(gstreamer-1.0), gstreamer-plugins-bad,
  gstreamer-plugins-base and gstreamer-plugins-good BuildRequires:
  No longer needed, runtime dependencies are enough.
* Fri Jan 11 2019 bjorn.lie@gmail.com
- Update to version 3.28.2:
  + Remote usage of conditional catch statements.
  + Rename icon to match appid, desktop file, about dialog and main
    window.
  + Updated translations.
- Drop gsr-Remove-usage-conditional-catch-statements.patch: Fixed
  upstream.
* Wed Dec 19 2018 bjorn.lie@gmail.com
- Add gsr-Remove-usage-conditional-catch-statements.patch: Remove
  usage of conditional catch statements. They are no longer
  supported in mozjs60.
* Tue Apr 10 2018 bjorn.lie@gmail.com
- Update to version 3.28.1:
  + Updated translations.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Mon Feb 12 2018 dimstar@opensuse.org
- Update to version 3.27.90:
  + bgo790682: Fix scoping error caused by deprecated "let"
    keyword.
  + build: Install appstream metadata to non-deprecated location.
* Mon Jan 15 2018 zaitor@opensuse.org
- Update to version 3.24.0.1+20171218.4d8a9a8:
  + gschema: Fix gettext-domain
  + Updated translations.
- Stop post(un) handling of glib2_gsettings_schema_post(un) and
  desktop_database_post(un), and drop
  glib2_gsettings_schema_requires macro file-triggers takes care of
  this for us now.
- Minor spec cleanup, use autosetup and make_build macros, pass
  disable-static to configure.
* Wed Mar 22 2017 zaitor@opensuse.org
- Update to version 3.24.0.1:
  + configure: Drop id3mux check failure to a warning.
  + Updated translations.
* Tue Mar 21 2017 dimstar@opensuse.org
- Update to version 3.24.0:
  + Fix codec errors caused by mono/stereo combobox.
  + Fix for Debian/Tails (bgo#777862).
  + Updated translations.
- Add pkgconfig(gstreamer-1.0) BuildRequires: new verified
  dependency.
- Add gstreamer-plugins-base, gstreamer-plugins-good and
  gstreamer-plugins-bad BuildRequires: newly verified build
  dependencies.
- Add gstreamer-plugins-base, gstreamer-plugins-good and
  gstreamer-plugins-bad Requires: the build dependency is merely to
  confirm the modules are present, but generally it would be
  runtime dependencies.
* Tue Sep 13 2016 zaitor@opensuse.org
- Update to version 3.21.92:
  + Updated translations.
* Fri Jul  1 2016 toddrme2178@gmail.com
- Fix Group tag.
* Mon May  9 2016 zaitor@opensuse.org
- Update to version 3.20.2:
  + Updated translations.
* Fri Apr 29 2016 zaitor@opensuse.org
- Update to version 3.19.92:
  + Deleting files did not refresh listview (bgo#765348).
* Sun Feb 28 2016 zaitor@opensuse.org
- Update to version 3.19.91:
  + Fix syntax error in icons Makefile.
  + Prevent stylesheet file deletion after 'make clean'.
  + Fix duplicate buttons in headerbar of about dialog.
  + Icon: provide a symbolic variant.
  + Format date created.
  + Create lookup table for files so retrieval for renaming is o(1)
    operation.
  + Updated translations.
* Thu Jan 21 2016 zaitor@opensuse.org
- Update to version 3.19.4:
  + Assign an icon to the application window.
  + Enable recodings in mono.
  + Set the correct application icon in the 'About' dialog.
  + Fix deprecated file creation mask.
  + Play when button is pressed even if row is not selected.
  + Updated translations.
* Mon Nov  9 2015 zaitor@opensuse.org
- Update to version 3.18.2:
  + Fix bgo#756993.
- Drop gsd-bgo756993-Check-for-null-clock.patch: Fixed upstream.
* Fri Oct 30 2015 zaitor@opensuse.org
- Add gsd-bgo756993-Check-for-null-clock.patch: Check for a null
  clock before getting the time. Crash fix from upstream git
  (bgo#756993).
* Tue Oct 13 2015 zaitor@opensuse.org
- Update to version 3.18.1:
  + Updated translations.
- Switch package to noarch BuildArch: There is no binary in this
  package.
* Wed Sep 16 2015 dimstar@opensuse.org
- Update to version 3.17.92:
  + No changes, only version bump.
* Mon Aug 31 2015 zaitor@opensuse.org
- Update to version 3.17.91:
  + Updated translations.
* Mon Aug 17 2015 zaitor@opensuse.org
- Update to version 3.17.90:
  + Updated translations.
* Mon May 25 2015 zaitor@opensuse.org
- Update to version 3.17.2:
  + Bugs fixed: bgo#744989.
* Thu Apr 30 2015 dimstar@opensuse.org
- Update to version 3.17.1:
  + Updated translations.
* Tue Mar 24 2015 dimstar@opensuse.org
- Update to version 3.16.0:
  + Updated translations.
* Mon Mar 16 2015 dimstar@opensuse.org
- Update to version 3.15.92:
  + Waveform bugfixes.
  + Updated translations.
* Tue Mar  3 2015 dimstar@opensuse.org
- Update to version 3.15.91:
  + Force symbolic link creation during installation.
  + Updated translations.
* Tue Feb 17 2015 dimstar@opensuse.org
- Update to version 3.15.90:
  + Correct overlapping of long titles and the date in main view.
  + Improve window size.
  + Improve file name assignment.
  + Replace margin_right and margin_left with margin_start and
    margin_end.
  + Updated translations.
* Wed Dec 17 2014 zaitor@opensuse.org
- Update to version 3.15.3:
  + Whitespace cleanup.
  + Add hours to the time label for recordings.
  + Fix line spacing.
  + Updated translations.
* Sun Nov  9 2014 zaitor@opensuse.org
- Update to version 3.14.2:
  + Updated translations.
* Mon Sep 22 2014 zaitor@opensuse.org
- Update to version 3.14.0.1:
  + Updated translations.
* Mon Sep 15 2014 zaitor@opensuse.org
- Update to version 3.14:
  + More css style fixes.
* Tue Sep  2 2014 zaitor@opensuse.org
- Update to version 3.13.91:
  + Add a HighContrast app icon.
  + Update css to work with new version of Adwaita.
* Tue Jul 22 2014 dimstar@opensuse.org
- Update to version 3.13.4:
  + Adapt for the package.js which is shipped by gjs.
  + Improve error handling.
  + Add AppData file.
* Mon Apr 14 2014 zaitor@opensuse.org
- Update to version 3.12.1:
  + Change Done button in Preferences dialog to close.
  + Add title to header bar in Info dialog.
  + Add accelerator for quit action.
  + Avoid calls to undefined vars in case of invalid audio
    settings.
- Changes from version 3.12.0:
  + No changes from version 3.11.92.
* Wed Mar 19 2014 zaitor@opensuse.org
- Update to version 3.11.92:
  + Include COPYING and AUTHORS files
  + Improve README and NEWS files.
* Mon Mar  3 2014 zaitor@opensuse.org
- Update to version 3.11.91:
  + Ui changes.
  + Bug fixes.
  + Updated translations.
- Drop gnome-sound-recorder-gettext.patch, fixed upstream.
- Drop gnome-common BuildRequires and call to gnome-autogen.sh: No
  longer required, as there are no patches left.
* Tue Dec 17 2013 dimstar@opensuse.org
- Initial package, version 3.11.3.
- Add gnome-sound-recorder-gettext.patch: Fix installation of
  translation's filenames.
